Enum aws_sdk_lexruntime::Error[][src]

#[non_exhaustive]
pub enum Error {
    BadGatewayException(BadGatewayException),
    BadRequestException(BadRequestException),
    ConflictException(ConflictException),
    DependencyFailedException(DependencyFailedException),
    InternalFailureException(InternalFailureException),
    LimitExceededException(LimitExceededException),
    LoopDetectedException(LoopDetectedException),
    NotAcceptableException(NotAcceptableException),
    NotFoundException(NotFoundException),
    RequestTimeoutException(RequestTimeoutException),
    UnsupportedMediaTypeException(UnsupportedMediaTypeException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
All possible error types for this service.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadGatewayException(BadGatewayException)

Either the Amazon Lex bot is still building, or one of the dependent services (Amazon Polly, AWS Lambda) failed with an internal service error.

Tuple Fields of BadGatewayException

0: BadGatewayException
BadRequestException(BadRequestException)

Request validation failed, there is no usable message in the context, or the bot build failed, is still in progress, or contains unbuilt changes.

Tuple Fields of BadRequestException

0: BadRequestException
ConflictException(ConflictException)

Two clients are using the same AWS account, Amazon Lex bot, and user ID.

Tuple Fields of ConflictException

0: ConflictException
DependencyFailedException(DependencyFailedException)

One of the dependencies, such as AWS Lambda or Amazon Polly, threw an exception. For example,

  • If Amazon Lex does not have sufficient permissions to call a Lambda function.

  • If a Lambda function takes longer than 30 seconds to execute.

  • If a fulfillment Lambda function returns a Delegate dialog action without removing any slot values.

Tuple Fields of DependencyFailedException

0: DependencyFailedException
InternalFailureException(InternalFailureException)

Internal service error. Retry the call.

Tuple Fields of InternalFailureException

0: InternalFailureException
LimitExceededException(LimitExceededException)

Exceeded a limit.

Tuple Fields of LimitExceededException

0: LimitExceededException
LoopDetectedException(LoopDetectedException)

This exception is not used.

Tuple Fields of LoopDetectedException

0: LoopDetectedException
NotAcceptableException(NotAcceptableException)

The accept header in the request does not have a valid value.

Tuple Fields of NotAcceptableException

0: NotAcceptableException
NotFoundException(NotFoundException)

The resource (such as the Amazon Lex bot or an alias) that is referred to is not found.

Tuple Fields of NotFoundException

0: NotFoundException
RequestTimeoutException(RequestTimeoutException)

The input speech is too long.

Tuple Fields of RequestTimeoutException

0: RequestTimeoutException
UnsupportedMediaTypeException(UnsupportedMediaTypeException)

The Content-Type header (PostContent API) has an invalid value.

Tuple Fields of UnsupportedMediaTypeException

0: UnsupportedMediaTypeException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unhandled error occurred.

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>