Enum aws_sdk_lexruntime::error::PutSessionErrorKind [−][src]
#[non_exhaustive]
pub enum PutSessionErrorKind {
BadGatewayException(BadGatewayException),
BadRequestException(BadRequestException),
ConflictException(ConflictException),
DependencyFailedException(DependencyFailedException),
InternalFailureException(InternalFailureException),
LimitExceededException(LimitExceededException),
NotAcceptableException(NotAcceptableException),
NotFoundException(NotFoundException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutSession operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadGatewayException(BadGatewayException)Either the Amazon Lex bot is still building, or one of the dependent services (Amazon Polly, AWS Lambda) failed with an internal service error.
Tuple Fields of BadGatewayException
BadRequestException(BadRequestException)Request validation failed, there is no usable message in the context, or the bot build failed, is still in progress, or contains unbuilt changes.
Tuple Fields of BadRequestException
ConflictException(ConflictException)Two clients are using the same AWS account, Amazon Lex bot, and user ID.
Tuple Fields of ConflictException
DependencyFailedException(DependencyFailedException)One of the dependencies, such as AWS Lambda or Amazon Polly, threw an exception. For example,
-
If Amazon Lex does not have sufficient permissions to call a Lambda function.
-
If a Lambda function takes longer than 30 seconds to execute.
-
If a fulfillment Lambda function returns a
Delegatedialog action without removing any slot values.
Tuple Fields of DependencyFailedException
InternalFailureException(InternalFailureException)Internal service error. Retry the call.
Tuple Fields of InternalFailureException
LimitExceededException(LimitExceededException)Exceeded a limit.
Tuple Fields of LimitExceededException
NotAcceptableException(NotAcceptableException)The accept header in the request does not have a valid value.
Tuple Fields of NotAcceptableException
NotFoundException(NotFoundException)The resource (such as the Amazon Lex bot or an alias) that is referred to is not found.
Tuple Fields of NotFoundException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code