Struct aws_sdk_lexruntime::model::GenericAttachment [−][src]
#[non_exhaustive]pub struct GenericAttachment {
pub title: Option<String>,
pub sub_title: Option<String>,
pub attachment_link_url: Option<String>,
pub image_url: Option<String>,
pub buttons: Option<Vec<Button>>,
}Expand description
Represents an option rendered to the user when a prompt is shown. It could be an image, a button, a link, or text.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the option.
sub_title: Option<String>The subtitle shown below the title.
attachment_link_url: Option<String>The URL of an attachment to the response card.
image_url: Option<String>The URL of an image that is displayed to the user.
The list of options to show to the user.
Implementations
Creates a new builder-style object to manufacture GenericAttachment