Struct aws_sdk_lexruntime::model::SentimentResponse [−][src]
#[non_exhaustive]pub struct SentimentResponse {
pub sentiment_label: Option<String>,
pub sentiment_score: Option<String>,
}Expand description
The sentiment expressed in an utterance.
When the bot is configured to send utterances to Amazon Comprehend for sentiment analysis, this field structure contains the result of the analysis.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sentiment_label: Option<String>The inferred sentiment that Amazon Comprehend has the highest confidence in.
sentiment_score: Option<String>The likelihood that the sentiment was correctly inferred.
Implementations
Creates a new builder-style object to manufacture SentimentResponse