Struct aws_sdk_lexruntime::output::PutSessionOutput [−][src]
#[non_exhaustive]pub struct PutSessionOutput {
pub content_type: Option<String>,
pub intent_name: Option<String>,
pub slots: Option<String>,
pub session_attributes: Option<String>,
pub message: Option<String>,
pub encoded_message: Option<String>,
pub message_format: Option<MessageFormatType>,
pub dialog_state: Option<DialogState>,
pub slot_to_elicit: Option<String>,
pub audio_stream: ByteStream,
pub session_id: Option<String>,
pub active_contexts: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content_type: Option<String>Content type as specified in the Accept HTTP header in
the request.
intent_name: Option<String>The name of the current intent.
slots: Option<String>Map of zero or more intent slots Amazon Lex detected from the user input during the conversation.
Amazon Lex creates a resolution list containing likely values for a slot.
The value that it returns is determined by the
valueSelectionStrategy selected when the slot type was
created or updated. If valueSelectionStrategy is set to
ORIGINAL_VALUE, the value provided by the user is returned,
if the user value is similar to the slot values. If
valueSelectionStrategy is set to
TOP_RESOLUTION Amazon Lex returns the first value in the
resolution list or, if there is no resolution list, null. If you don't
specify a valueSelectionStrategy the default is
ORIGINAL_VALUE.
session_attributes: Option<String>Map of key/value pairs representing session-specific context information.
message: Option<String>The next message that should be presented to the user.
You can only use this field in the de-DE, en-AU, en-GB, en-US, es-419,
es-ES, es-US, fr-CA, fr-FR, and it-IT locales. In all other locales, the
message field is null. You should use the
encodedMessage field instead.
encoded_message: Option<String>The next message that should be presented to the user.
The encodedMessage field is base-64 encoded. You must
decode the field before you can use the value.
message_format: Option<MessageFormatType>The format of the response message. One of the following values:
-
PlainText- The message contains plain UTF-8 text. -
CustomPayload- The message is a custom format for the client. -
SSML- The message contains text formatted for voice output. -
Composite- The message contains an escaped JSON object containing one or more messages from the groups that messages were assigned to when the intent was created.
dialog_state: Option<DialogState>-
ConfirmIntent- Amazon Lex is expecting a "yes" or "no" response to confirm the intent before fulfilling an intent. -
ElicitIntent- Amazon Lex wants to elicit the user's intent. -
ElicitSlot- Amazon Lex is expecting the value of a slot for the current intent. -
Failed- Conveys that the conversation with the user has failed. This can happen for various reasons, including the user does not provide an appropriate response to prompts from the service, or if the Lambda function fails to fulfill the intent. -
Fulfilled- Conveys that the Lambda function has sucessfully fulfilled the intent. -
ReadyForFulfillment- Conveys that the client has to fulfill the intent.
slot_to_elicit: Option<String>If the dialogState is ElicitSlot, returns
the name of the slot for which Amazon Lex is eliciting a value.
audio_stream: ByteStreamThe audio version of the message to convey to the user.
session_id: Option<String>A unique identifier for the session.
active_contexts: Option<String>A list of active contexts for the session.
Implementations
Creates a new builder-style object to manufacture PutSessionOutput