Module aws_sdk_lexruntime::error [−][src]
Errors that can occur when calling the service.
Modules
Structs
Either the Amazon Lex bot is still building, or one of the dependent
Request validation failed, there is no usable message in the context,
Two clients are using the same AWS account, Amazon Lex bot, and user
Error type for the DeleteSession operation.
One of the dependencies, such as AWS Lambda or Amazon Polly, threw an
Error type for the GetSession operation.
Internal service error. Retry the call.
Exceeded a limit.
This exception is not used.
The accept header in the request does not have a valid value.
The resource (such as the Amazon Lex bot or an alias) that is referred
Error type for the PostContent operation.
Error type for the PostText operation.
Error type for the PutSession operation.
The input speech is too long.
The Content-Type header (PostContent API) has an invalid
Enums
Types of errors that can occur for the DeleteSession operation.
Types of errors that can occur for the GetSession operation.
Types of errors that can occur for the PostContent operation.
Types of errors that can occur for the PostText operation.
Types of errors that can occur for the PutSession operation.