pub struct PostTextFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PostText.
Sends user input to Amazon Lex. Client applications can use this API to send requests to Amazon Lex at runtime. Amazon Lex then interprets the user input using the machine learning model it built for the bot.
In response, Amazon Lex returns the next message to convey to the user an optional responseCard to display. Consider the following example messages:
-
For a user input "I would like a pizza", Amazon Lex might return a response with a message eliciting slot data (for example, PizzaSize): "What size pizza would you like?"
-
After the user provides all of the pizza order information, Amazon Lex might return a response with a message to obtain user confirmation "Proceed with the pizza order?".
-
After the user replies to a confirmation prompt with a "yes", Amazon Lex might return a conclusion statement: "Thank you, your cheese pizza has been ordered.".
Not all Amazon Lex messages require a user response. For example, a conclusion statement does not require a response. Some messages require only a "yes" or "no" user response. In addition to the message, Amazon Lex provides additional context about the message in the response that you might use to enhance client behavior, for example, to display the appropriate client user interface. These are the slotToElicit, dialogState, intentName, and slots fields in the response. Consider the following examples:
-
If the message is to elicit slot data, Amazon Lex returns the following context information:
-
dialogStateset to ElicitSlot -
intentNameset to the intent name in the current context -
slotToElicitset to the slot name for which themessageis eliciting information -
slotsset to a map of slots, configured for the intent, with currently known values
-
-
If the message is a confirmation prompt, the
dialogStateis set to ConfirmIntent andSlotToElicitis set to null. -
If the message is a clarification prompt (configured for the intent) that indicates that user intent is not understood, the
dialogStateis set to ElicitIntent andslotToElicitis set to null.
In addition, Amazon Lex also returns your application-specific sessionAttributes. For more information, see Managing Conversation Context.
Implementations
Sourceimpl PostTextFluentBuilder
impl PostTextFluentBuilder
Sourcepub fn as_input(&self) -> &PostTextInputBuilder
pub fn as_input(&self) -> &PostTextInputBuilder
Access the PostText as a reference.
Sourcepub async fn send(
self,
) -> Result<PostTextOutput, SdkError<PostTextError, HttpResponse>>
pub async fn send( self, ) -> Result<PostTextOutput, SdkError<PostTextError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PostTextOutput, PostTextError, Self>
pub fn customize( self, ) -> CustomizableOperation<PostTextOutput, PostTextError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_bot_name(self, input: Option<String>) -> Self
pub fn set_bot_name(self, input: Option<String>) -> Self
The name of the Amazon Lex bot.
Sourcepub fn get_bot_name(&self) -> &Option<String>
pub fn get_bot_name(&self) -> &Option<String>
The name of the Amazon Lex bot.
Sourcepub fn set_bot_alias(self, input: Option<String>) -> Self
pub fn set_bot_alias(self, input: Option<String>) -> Self
The alias of the Amazon Lex bot.
Sourcepub fn get_bot_alias(&self) -> &Option<String>
pub fn get_bot_alias(&self) -> &Option<String>
The alias of the Amazon Lex bot.
Sourcepub fn user_id(self, input: impl Into<String>) -> Self
pub fn user_id(self, input: impl Into<String>) -> Self
The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. At runtime, each request must contain the userID field.
To decide the user ID to use for your application, consider the following factors.
-
The
userIDfield must not contain any personally identifiable information of the user, for example, name, personal identification numbers, or other end user personal information. -
If you want a user to start a conversation on one device and continue on another device, use a user-specific identifier.
-
If you want the same user to be able to have two independent conversations on two different devices, choose a device-specific identifier.
-
A user can't have two independent conversations with two different versions of the same bot. For example, a user can't have a conversation with the PROD and BETA versions of the same bot. If you anticipate that a user will need to have conversation with two different versions, for example, while testing, include the bot alias in the user ID to separate the two conversations.
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
pub fn set_user_id(self, input: Option<String>) -> Self
The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. At runtime, each request must contain the userID field.
To decide the user ID to use for your application, consider the following factors.
-
The
userIDfield must not contain any personally identifiable information of the user, for example, name, personal identification numbers, or other end user personal information. -
If you want a user to start a conversation on one device and continue on another device, use a user-specific identifier.
-
If you want the same user to be able to have two independent conversations on two different devices, choose a device-specific identifier.
-
A user can't have two independent conversations with two different versions of the same bot. For example, a user can't have a conversation with the PROD and BETA versions of the same bot. If you anticipate that a user will need to have conversation with two different versions, for example, while testing, include the bot alias in the user ID to separate the two conversations.
Sourcepub fn get_user_id(&self) -> &Option<String>
pub fn get_user_id(&self) -> &Option<String>
The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. At runtime, each request must contain the userID field.
To decide the user ID to use for your application, consider the following factors.
-
The
userIDfield must not contain any personally identifiable information of the user, for example, name, personal identification numbers, or other end user personal information. -
If you want a user to start a conversation on one device and continue on another device, use a user-specific identifier.
-
If you want the same user to be able to have two independent conversations on two different devices, choose a device-specific identifier.
-
A user can't have two independent conversations with two different versions of the same bot. For example, a user can't have a conversation with the PROD and BETA versions of the same bot. If you anticipate that a user will need to have conversation with two different versions, for example, while testing, include the bot alias in the user ID to separate the two conversations.
Sourcepub fn session_attributes(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn session_attributes( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to sessionAttributes.
To override the contents of this collection use set_session_attributes.
Application-specific information passed between Amazon Lex and a client application.
For more information, see Setting Session Attributes.
Sourcepub fn set_session_attributes(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_session_attributes( self, input: Option<HashMap<String, String>>, ) -> Self
Application-specific information passed between Amazon Lex and a client application.
For more information, see Setting Session Attributes.
Sourcepub fn get_session_attributes(&self) -> &Option<HashMap<String, String>>
pub fn get_session_attributes(&self) -> &Option<HashMap<String, String>>
Application-specific information passed between Amazon Lex and a client application.
For more information, see Setting Session Attributes.
Sourcepub fn request_attributes(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn request_attributes( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to requestAttributes.
To override the contents of this collection use set_request_attributes.
Request-specific information passed between Amazon Lex and a client application.
The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:.
For more information, see Setting Request Attributes.
Sourcepub fn set_request_attributes(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_request_attributes( self, input: Option<HashMap<String, String>>, ) -> Self
Request-specific information passed between Amazon Lex and a client application.
The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:.
For more information, see Setting Request Attributes.
Sourcepub fn get_request_attributes(&self) -> &Option<HashMap<String, String>>
pub fn get_request_attributes(&self) -> &Option<HashMap<String, String>>
Request-specific information passed between Amazon Lex and a client application.
The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:.
For more information, see Setting Request Attributes.
Sourcepub fn input_text(self, input: impl Into<String>) -> Self
pub fn input_text(self, input: impl Into<String>) -> Self
The text that the user entered (Amazon Lex interprets this text).
Sourcepub fn set_input_text(self, input: Option<String>) -> Self
pub fn set_input_text(self, input: Option<String>) -> Self
The text that the user entered (Amazon Lex interprets this text).
Sourcepub fn get_input_text(&self) -> &Option<String>
pub fn get_input_text(&self) -> &Option<String>
The text that the user entered (Amazon Lex interprets this text).
Sourcepub fn active_contexts(self, input: ActiveContext) -> Self
pub fn active_contexts(self, input: ActiveContext) -> Self
Appends an item to activeContexts.
To override the contents of this collection use set_active_contexts.
A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request,
If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared.
Sourcepub fn set_active_contexts(self, input: Option<Vec<ActiveContext>>) -> Self
pub fn set_active_contexts(self, input: Option<Vec<ActiveContext>>) -> Self
A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request,
If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared.
Sourcepub fn get_active_contexts(&self) -> &Option<Vec<ActiveContext>>
pub fn get_active_contexts(&self) -> &Option<Vec<ActiveContext>>
A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request,
If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared.